fnss.traffic.eventscheduling.EventSchedule.add_schedule — FNSS 0.7.0 documentation

# fnss.traffic.eventscheduling.EventSchedule.add_schedule

`EventSchedule.` `add_schedule`(event_schedule)

  Merge with another event schedule.

  This method takes all the events of the schedule passed as argument and add them to the event schedule it belongs to. The events of the schedule after the merging are still chronologically sorted.

  Parameters: | event_schedule : EventSchedule The event schedule whose events are added to this one.

  Notes

  All the events are sorted